@@ -45,20 +45,31 @@ end_time = datetime.datetime(trading_day.year, trading_day.month, trading_day.da
 #     index += 1
 
 
-begin_trading_date = datetime.datetime(2017, 6, 30)
-end_trading_date = datetime.datetime(2017, 7, 5)
+# begin_trading_date = datetime.datetime(2017, 7, 4)
+# end_trading_date = datetime.datetime(2017, 7, 5)
+# instrument_id = "rb9999"
+# interval = 1
+# bar_type = EnumBarType.minute
+# bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
+# index = 1
+# for bar in bar_series:
+#     print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close))
+#     index += 1
+
+begin_trading_date = datetime.datetime(2017, 7, 4, 13, 54, 0)
+end_trading_date = datetime.datetime(2017, 7, 5, 10, 9, 0)
 instrument_id = "rb9999"
-interval = 1
-bar_type = EnumBarType.day
-bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
+interval = 5
+bar_type = EnumBarType.minute
+bar_series = qi_data_controller.load_bar_series_by_date_time(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
 index = 1
 for bar in bar_series:
     print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close))
     index += 1
 
 # length = 20
-# end_trading_date = datetime.datetime(2019, 5, 7)
-# instrument_id = "IF9999"
+# end_trading_date = datetime.datetime(2019, 5, 7, 0, 0, 0)
+# instrument_id = "ag9999"
 # interval = 5
 # bar_type = EnumBarType.minute
 # bar_series = qi_data_controller.load_bar_series_by_length(EnumMarket.期货, instrument_id, interval, bar_type, length, end_trading_date)
